
from setuptools import setup

setup(name='chemkin',
      version='0.6',
      description='The best chemkin package',
      url='https://github.com/G12-cs207-FinalProject/cs207-FinalProject.git',
      author='Parser',
      license='Harvard',
      packages=['chemkin']
)